==> bow-ui-0.5-sources.jar: org/chorem/bow/BowProxy.java <==
/*
 * #%L
 * bow
 * 
 * $Id: BowProxy.java 242 2011-04-19 06:36:19Z kmorin $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-0.5/bow-ui/src/main/java/org/chorem/bow/BowProxy.java $
 * %%
 * Copyright (C) 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import org.nuiton.util.ApplicationConfig;
import org.nuiton.wikitty.WikittyProxy;
import org.nuiton.wikitty.WikittyService;
import org.nuiton.wikitty.WikittyServiceFactory;
import org.nuiton.wikitty.entities.WikittyExtension;

import java.util.ArrayList;
import java.util.List;

/**
 * Proxy pour utiliser les wikitty convenablement initialise.
 *
 * @author poussin
 * @version $Revision: 242 $
 *
 * Last update: $Date: 2011-04-19 08:36:19 +0200 (mar., 19 avril 2011) $
 * by : $Author: kmorin $
 */
public class BowProxy extends WikittyProxy {

    static protected WikittyService ws = null;

    protected BowProxy(BowConfig config, WikittyService ws) {
        super(config, ws);
    }

    /**
     * Return instance of BowProxy with specified security token
     *
     * @param token
     * @return
     */
    static public BowProxy getInstance(String token) {
        BowConfig config = BowConfig.getInstance();
        WikittyService ws = getWikittyService(config);
        BowProxy result = new BowProxy(config, ws);
        result.setSecurityToken(token);
        
        return result;
    }

    /**
     * Return WikittyService to use. This WikittyService is singleton.
     *
     * @param config
     * @return
     */
    static protected WikittyService getWikittyService(ApplicationConfig config) {
        if (ws == null) {
            synchronized(BowProxy.class) {
                if (ws == null) {                    
                    List<WikittyExtension> extensions = new ArrayList<WikittyExtension>();
                    extensions.addAll(BowPreferenceImpl.extensions); // inherit BowUSer, WikittyUser
                    extensions.addAll(BowImportImpl.extensions); // inherit BowBookmark, WikittyLabel

                    ws = WikittyServiceFactory.buildWikittyService(config);
                    ws.storeExtension(null, extensions);
                }
            }
        }
        return ws;
    }
    
}

==> bow-ui-1.0-sources.jar: org/chorem/bow/BowProxy.java <==
/*
 * #%L
 * bow
 * 
 * $Id: BowProxy.java 282 2011-05-12 12:03:04Z sletellier $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.0/bow-ui/src/main/java/org/chorem/bow/BowProxy.java $
 * %%
 * Copyright (C) 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import org.nuiton.util.ApplicationConfig;
import org.nuiton.wikitty.WikittyProxy;
import org.nuiton.wikitty.WikittyService;
import org.nuiton.wikitty.WikittyServiceFactory;
import org.nuiton.wikitty.entities.WikittyExtension;

import java.util.ArrayList;
import java.util.List;

/**
 * Proxy pour utiliser les wikitty convenablement initialise.
 *
 * @author poussin
 * @version $Revision: 282 $
 *
 * Last update: $Date: 2011-05-12 14:03:04 +0200 (jeu., 12 mai 2011) $
 * by : $Author: sletellier $
 */
public class BowProxy extends WikittyProxy {

    static protected WikittyService ws = null;

    protected BowProxy(ApplicationConfig config, WikittyService ws) {
        super(config, ws);
    }

    /**
     * Return instance of BowProxy with specified security token
     *
     * @param token
     * @return
     */
    static public BowProxy getInstance(String token) {
        ApplicationConfig config = BowConfig.getConfig();
        WikittyService ws = getWikittyService(config);
        BowProxy result = new BowProxy(config, ws);
        result.setSecurityToken(token);
        
        return result;
    }

    /**
     * Return WikittyService to use. This WikittyService is singleton.
     *
     * @param config
     * @return
     */
    static protected WikittyService getWikittyService(ApplicationConfig config) {
        if (ws == null) {
            synchronized(BowProxy.class) {
                if (ws == null) {                    
                    List<WikittyExtension> extensions = new ArrayList<WikittyExtension>();
                    extensions.addAll(BowPreferenceImpl.extensions); // inherit BowUSer, WikittyUser
                    extensions.addAll(BowImportImpl.extensions); // inherit BowBookmark, WikittyLabel

                    ws = WikittyServiceFactory.buildWikittyService(config);
                    ws.storeExtension(null, extensions);
                }
            }
        }
        return ws;
    }
    
}
